Documentation
¶
Index ¶
- Constants
- Variables
- func And(predicates ...predicate.User) predicate.User
- func CreatedAt(v time.Time) predicate.User
- func CreatedAtEQ(v time.Time) predicate.User
- func CreatedAtGT(v time.Time) predicate.User
- func CreatedAtGTE(v time.Time) predicate.User
- func CreatedAtIn(vs ...time.Time) predicate.User
- func CreatedAtLT(v time.Time) predicate.User
- func CreatedAtLTE(v time.Time) predicate.User
- func CreatedAtNEQ(v time.Time) predicate.User
- func CreatedAtNotIn(vs ...time.Time) predicate.User
- func HasGuilds() predicate.User
- func HasGuildsWith(preds ...predicate.Member) predicate.User
- func HasOwnGuilds() predicate.User
- func HasOwnGuildsWith(preds ...predicate.Guild) predicate.User
- func HasWordSuffix() predicate.User
- func HasWordSuffixWith(preds ...predicate.WordSuffix) predicate.User
- func ID(id snowflake.ID) predicate.User
- func IDEQ(id snowflake.ID) predicate.User
- func IDGT(id snowflake.ID) predicate.User
- func IDGTE(id snowflake.ID) predicate.User
- func IDIn(ids ...snowflake.ID) predicate.User
- func IDLT(id snowflake.ID) predicate.User
- func IDLTE(id snowflake.ID) predicate.User
- func IDNEQ(id snowflake.ID) predicate.User
- func IDNotIn(ids ...snowflake.ID) predicate.User
- func Locale(v discord.Locale) predicate.User
- func LocaleContains(v discord.Locale) predicate.User
- func LocaleContainsFold(v discord.Locale) predicate.User
- func LocaleEQ(v discord.Locale) predicate.User
- func LocaleEqualFold(v discord.Locale) predicate.User
- func LocaleGT(v discord.Locale) predicate.User
- func LocaleGTE(v discord.Locale) predicate.User
- func LocaleHasPrefix(v discord.Locale) predicate.User
- func LocaleHasSuffix(v discord.Locale) predicate.User
- func LocaleIn(vs ...discord.Locale) predicate.User
- func LocaleLT(v discord.Locale) predicate.User
- func LocaleLTE(v discord.Locale) predicate.User
- func LocaleNEQ(v discord.Locale) predicate.User
- func LocaleNotIn(vs ...discord.Locale) predicate.User
- func Name(v string) predicate.User
- func NameContains(v string) predicate.User
- func NameContainsFold(v string) predicate.User
- func NameEQ(v string) predicate.User
- func NameEqualFold(v string) predicate.User
- func NameGT(v string) predicate.User
- func NameGTE(v string) predicate.User
- func NameHasPrefix(v string) predicate.User
- func NameHasSuffix(v string) predicate.User
- func NameIn(vs ...string) predicate.User
- func NameLT(v string) predicate.User
- func NameLTE(v string) predicate.User
- func NameNEQ(v string) predicate.User
- func NameNotIn(vs ...string) predicate.User
- func Not(p predicate.User) predicate.User
- func Or(predicates ...predicate.User) predicate.User
- func ValidColumn(column string) bool
- func Xp(v xppoint.XP) predicate.User
- func XpEQ(v xppoint.XP) predicate.User
- func XpGT(v xppoint.XP) predicate.User
- func XpGTE(v xppoint.XP) predicate.User
- func XpIn(vs ...xppoint.XP) predicate.User
- func XpLT(v xppoint.XP) predicate.User
- func XpLTE(v xppoint.XP) predicate.User
- func XpNEQ(v xppoint.XP) predicate.User
- func XpNotIn(vs ...xppoint.XP) predicate.User
- type OrderOption
- func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
- func ByGuilds(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByGuildsCount(opts ...sql.OrderTermOption) OrderOption
- func ByID(opts ...sql.OrderTermOption) OrderOption
- func ByLocale(opts ...sql.OrderTermOption) OrderOption
- func ByName(opts ...sql.OrderTermOption) OrderOption
- func ByOwnGuilds(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByOwnGuildsCount(opts ...sql.OrderTermOption) OrderOption
- func ByWordSuffix(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
- func ByWordSuffixCount(opts ...sql.OrderTermOption) OrderOption
- func ByXp(opts ...sql.OrderTermOption) OrderOption
Constants ¶
const ( // Label holds the string label denoting the user type in the database. Label = "user" // FieldID holds the string denoting the id field in the database. FieldID = "id" // FieldName holds the string denoting the name field in the database. FieldName = "name" // FieldCreatedAt holds the string denoting the created_at field in the database. FieldCreatedAt = "created_at" // FieldLocale holds the string denoting the locale field in the database. FieldLocale = "locale" // FieldXp holds the string denoting the xp field in the database. FieldXp = "xp" // EdgeOwnGuilds holds the string denoting the own_guilds edge name in mutations. EdgeOwnGuilds = "own_guilds" // EdgeGuilds holds the string denoting the guilds edge name in mutations. EdgeGuilds = "guilds" // EdgeWordSuffix holds the string denoting the word_suffix edge name in mutations. EdgeWordSuffix = "word_suffix" // Table holds the table name of the user in the database. Table = "users" // OwnGuildsTable is the table that holds the own_guilds relation/edge. OwnGuildsTable = "guilds" // OwnGuildsInverseTable is the table name for the Guild entity. // It exists in this package in order to avoid circular dependency with the "guild" package. OwnGuildsInverseTable = "guilds" // OwnGuildsColumn is the table column denoting the own_guilds relation/edge. OwnGuildsColumn = "user_own_guilds" // GuildsTable is the table that holds the guilds relation/edge. GuildsTable = "members" // GuildsInverseTable is the table name for the Member entity. // It exists in this package in order to avoid circular dependency with the "member" package. GuildsInverseTable = "members" // GuildsColumn is the table column denoting the guilds relation/edge. GuildsColumn = "user_id" // WordSuffixTable is the table that holds the word_suffix relation/edge. WordSuffixTable = "word_suffixes" // WordSuffixInverseTable is the table name for the WordSuffix entity. // It exists in this package in order to avoid circular dependency with the "wordsuffix" package. WordSuffixInverseTable = "word_suffixes" // WordSuffixColumn is the table column denoting the word_suffix relation/edge. WordSuffixColumn = "user_word_suffix" )
Variables ¶
var ( // NameValidator is a validator for the "name" field. It is called by the builders before save. NameValidator func(string) error // DefaultCreatedAt holds the default value on creation for the "created_at" field. DefaultCreatedAt func() time.Time // DefaultLocale holds the default value on creation for the "locale" field. DefaultLocale discord.Locale // LocaleValidator is a validator for the "locale" field. It is called by the builders before save. LocaleValidator func(string) error // DefaultXp holds the default value on creation for the "xp" field. DefaultXp xppoint.XP )
var Columns = []string{ FieldID, FieldName, FieldCreatedAt, FieldLocale, FieldXp, }
Columns holds all SQL columns for user fields.
Functions ¶
func CreatedAt ¶
CreatedAt applies equality check predicate on the "created_at" field. It's identical to CreatedAtEQ.
func CreatedAtEQ ¶
CreatedAtEQ applies the EQ predicate on the "created_at" field.
func CreatedAtGT ¶
CreatedAtGT applies the GT predicate on the "created_at" field.
func CreatedAtGTE ¶
CreatedAtGTE applies the GTE predicate on the "created_at" field.
func CreatedAtIn ¶
CreatedAtIn applies the In predicate on the "created_at" field.
func CreatedAtLT ¶
CreatedAtLT applies the LT predicate on the "created_at" field.
func CreatedAtLTE ¶
CreatedAtLTE applies the LTE predicate on the "created_at" field.
func CreatedAtNEQ ¶
CreatedAtNEQ applies the NEQ predicate on the "created_at" field.
func CreatedAtNotIn ¶
CreatedAtNotIn applies the NotIn predicate on the "created_at" field.
func HasGuildsWith ¶
HasGuildsWith applies the HasEdge predicate on the "guilds" edge with a given conditions (other predicates).
func HasOwnGuilds ¶
HasOwnGuilds applies the HasEdge predicate on the "own_guilds" edge.
func HasOwnGuildsWith ¶
HasOwnGuildsWith applies the HasEdge predicate on the "own_guilds" edge with a given conditions (other predicates).
func HasWordSuffix ¶
HasWordSuffix applies the HasEdge predicate on the "word_suffix" edge.
func HasWordSuffixWith ¶
func HasWordSuffixWith(preds ...predicate.WordSuffix) predicate.User
HasWordSuffixWith applies the HasEdge predicate on the "word_suffix" edge with a given conditions (other predicates).
func Locale ¶
Locale applies equality check predicate on the "locale" field. It's identical to LocaleEQ.
func LocaleContains ¶
LocaleContains applies the Contains predicate on the "locale" field.
func LocaleContainsFold ¶
LocaleContainsFold applies the ContainsFold predicate on the "locale" field.
func LocaleEqualFold ¶
LocaleEqualFold applies the EqualFold predicate on the "locale" field.
func LocaleHasPrefix ¶
LocaleHasPrefix applies the HasPrefix predicate on the "locale" field.
func LocaleHasSuffix ¶
LocaleHasSuffix applies the HasSuffix predicate on the "locale" field.
func LocaleNotIn ¶
LocaleNotIn applies the NotIn predicate on the "locale" field.
func NameContains ¶
NameContains applies the Contains predicate on the "name" field.
func NameContainsFold ¶
NameContainsFold applies the ContainsFold predicate on the "name" field.
func NameEqualFold ¶
NameEqualFold applies the EqualFold predicate on the "name" field.
func NameHasPrefix ¶
NameHasPrefix applies the HasPrefix predicate on the "name" field.
func NameHasSuffix ¶
NameHasSuffix applies the HasSuffix predicate on the "name" field.
func ValidColumn ¶
ValidColumn reports if the column name is valid (part of the table columns).
Types ¶
type OrderOption ¶
OrderOption defines the ordering options for the User queries.
func ByCreatedAt ¶
func ByCreatedAt(opts ...sql.OrderTermOption) OrderOption
ByCreatedAt orders the results by the created_at field.
func ByGuilds ¶
func ByGuilds(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByGuilds orders the results by guilds terms.
func ByGuildsCount ¶
func ByGuildsCount(opts ...sql.OrderTermOption) OrderOption
ByGuildsCount orders the results by guilds count.
func ByID ¶
func ByID(opts ...sql.OrderTermOption) OrderOption
ByID orders the results by the id field.
func ByLocale ¶
func ByLocale(opts ...sql.OrderTermOption) OrderOption
ByLocale orders the results by the locale field.
func ByName ¶
func ByName(opts ...sql.OrderTermOption) OrderOption
ByName orders the results by the name field.
func ByOwnGuilds ¶
func ByOwnGuilds(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByOwnGuilds orders the results by own_guilds terms.
func ByOwnGuildsCount ¶
func ByOwnGuildsCount(opts ...sql.OrderTermOption) OrderOption
ByOwnGuildsCount orders the results by own_guilds count.
func ByWordSuffix ¶
func ByWordSuffix(term sql.OrderTerm, terms ...sql.OrderTerm) OrderOption
ByWordSuffix orders the results by word_suffix terms.
func ByWordSuffixCount ¶
func ByWordSuffixCount(opts ...sql.OrderTermOption) OrderOption
ByWordSuffixCount orders the results by word_suffix count.
func ByXp ¶
func ByXp(opts ...sql.OrderTermOption) OrderOption
ByXp orders the results by the xp field.